@@ -1,20 +1,17 @@
+#ifdef WIN_MAC
+#include <Carbon.h> /* must be before <vib*.h> or it does not compile */
+#endif
+
+#include <math.h>
+#include <ctype.h>
 #include <vibtypes.h>
 #include <vibprocs.h>
-#include <math.h>
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
-#include <ctype.h>
 
 #if defined(WIN_MSWIN) || defined (WIN_MAC)
 #define  MICRO
 #endif
 
 #ifdef WIN_MAC
-#include <Quickdraw.h>
-#include <Files.h>
-#include <Scrap.h>
-#include <Types.h>
 #ifndef M_PI
 #define M_PI           3.14159265358979323846  /* pi */
 #endif
